AB-BLAST PostScript™ Output

## AB-BLAST 3.0 PostScript™ Output

### PostScript™ Output Description

A minimalistic PostScript™ output is available from AB-BLAST 3.0 when `mformat=5` is specified on the command line. The output is a crude, 2-dimensional schematic representation of the HSPs found. The resultant output files can be printed “as is” on PostScript™ printers but will eat reams of paper, at a rate of one page per reported database sequence! You have been warned!!! Files can be viewed directly in some PostScript™ viewers, or converted to PDF for viewing by an application such as Adobe Reader. For more convenient conversion to PDF using a program such as Adobe PDF Distiller, you may want to save the output to a file having a `.ps` extension on its name. The tools gimp-print, ps2pdf and ghostscript may also aid in converting from PostScript™ to PDF.

PostScript™ is a registered trademark of Adobe Systems, Inc.

Last modified: 2009-01-15

Return to the AB-BLAST Archives home page